package fr.cnam.projet;

import fr.cnam.ihm.*;

// Classe de definition de l'IHM principale du projet
// Cette ihm gere la plate-forme de jeu.
//  L'heritage de AdaptaterControlesCanvasIHM permet de gerer le clic dans une case
//    de la grille de jeu
//  L'interface FormulaireInt permet de gerer les actions dans les objets d'ihm
//
public class IHMPFJeu extends AdaptaterControlesCanvasIHM implements FormulaireInt
                                                                     // 
{
  private PFJeu pfjeu;    // La plate forme de jeu
  CanvasIHM grille;       // La grille de jeu
  Formulaire form;        // Le formulaire de l'ihm principale

  // Constructeur
  //
  public IHMPFJeu(PFJeu pfjeu)
  {
    // L'applicatif de l'IHM
    //
    this.pfjeu = pfjeu;
    
    // Creation du formulaire
    //
    this.form = new Formulaire("Plate-forme de jeu",this,1200,730);
        
    //  Creation des elements de l'IHM
    //
    form.addLabel("Afficher tous les joueurs");
    form.addButton("AFF_JOUEURS","Tous les joueurs");
    form.addLabel("");
    form.addLabel("Afficher toutes les partes");
    form.addButton("AFF_PARTIES","Toutes les parties");
    form.addLabel("");

    form.addZoneText("RESULTATS","Resultats",
                     true,
                     "",
                     380,400);

    form.setPosition(400,0);
    grille = form.addGrilleIHM(Othello.NB_LIGNE,
                               Othello.NB_COLONNE,40,this);

    // Affichage du formulaire
    //
    form.afficher();
    
    // Initialisation de l'applicatif
    //  On affiche le resultat de l'initialisation
    //
    String res = pfjeu.initialiser(this);
    form.setValeurChamp("RESULTATS",res);
  }


  // Methode appellee quand on clique dans un objet d'ihm
  //
  public void submit(Formulaire form,String nomSubmit)
  {

    // Affichage de tous les produits du stock
    //
    if (nomSubmit.equals("AFF_JOUEURS"))
      {
        String res = pfjeu.listerTousJoueurs();
        form.setValeurChamp("RESULTATS",res);
      }

    // Affichage de toutes les commandes
    //
    if (nomSubmit.equals("AFF_PARTIES"))
      {
        String res = pfjeu.listerToutesParties();
        form.setValeurChamp("RESULTATS",res);
      }
  }

  // Methode appellee quand on clique dans une case de la grille
  //
  public void pointerCaseGrille(int xCase,int yCase,CanvasIHM ihm)
  {
    // Selection d'une case dans un jeu d'othello
    pfjeu.getOthello().selectionnerCase(xCase,yCase);
  }

  // Methode elementaire permettant d'afficher une ligne de texte
  //  dans la zone de resultats de l'ihm principale
  //
  public void afficherResultat(String res)
  {
    if (res.equals("")) form.setValeurChamp("RESULTATS","");
    else form.setValeurChamp("RESULTATS",form.getValeurChamp("RESULTATS")+"\n"+res);
  }

  // Getteurs
  //
  public CanvasIHM getGrille(){return grille;}
}